﻿using System;
using System.Diagnostics;

namespace uptime
{
    class Program
    {
        static void Main(string[] args)
        {
            if (args.Length > 0)
            {
                if (args[0] == "-r")
                {
                    Console.WriteLine("Uptime record: " + getUptime(Properties.Settings.Default.longest));
                }
                else
                {
                    Console.WriteLine("Uptime Utility by Matthew Malensek");
                    Console.WriteLine();
                    Console.WriteLine("Run with no arguments to get the current system uptime.");
                    Console.WriteLine("To display the longest recorded uptime, run with the -r command line switch.");
                }
            }
            else
            {
                PerformanceCounter pC = new PerformanceCounter("System", "System Up Time");
                pC.NextValue();

                TimeSpan time = TimeSpan.FromSeconds(pC.NextValue());
                if (time > Properties.Settings.Default.longest)
                {
                    Properties.Settings.Default.longest = time;
                    Properties.Settings.Default.Save();
                }

                DateTime now = DateTime.Now;

                String uptime = now.ToLongDateString() + "\n";
                uptime += "Uptime: " + getUptime(time);

                Console.WriteLine(uptime);
            }
        }

        /// <summary>
        /// Generates an uptime string
        /// </summary>
        /// <param name="t">TimeSpan to format</param>
        /// <returns>Formatted string with the uptime value</returns>
        public static String getUptime(TimeSpan t)
        {
            String uptime = "";

            if (t.Days > 0)
            {
                uptime += t.Days + " days, ";
            }
            if (t.Hours > 0)
            {
                uptime += t.Hours + " hours, ";
            }
            if (t.Minutes > 0)
            {
                uptime += t.Minutes + " minutes, ";
            }

            uptime += t.Seconds + " seconds";

            return uptime;
        }
    }
}
